@@ -10,13 +10,12 @@ import zipfile
 
 from lxml import etree
 
-from docx2python.attribute_register import Tags
+from docx2python.attribute_register import Tags, get_prefixed_tag
 from docx2python.docx_context import collect_numFmts
 from docx2python.docx_reader import DocxReader
 from docx2python.iterators import iter_at_depth
 from docx2python.main import docx2python
-
-from .conftest import RESOURCES
+from tests.conftest import RESOURCES
 
 example_docx = RESOURCES / "example.docx"
 
@@ -37,7 +36,7 @@ class TestSaveDocx:
         """Creates a valid docx and updates text"""
         input_context = DocxReader(example_docx)
         input_xml = input_context.file_of_type("officeDocument").root_element
-        for elem in (x for x in input_xml.iter() if x.tag == Tags.TEXT):
+        for elem in (x for x in input_xml.iter() if get_prefixed_tag(x) == Tags.TEXT):
             if not elem.text:
                 continue
             elem.text = elem.text.replace("bullet", "BULLET")
@@ -45,7 +44,7 @@ class TestSaveDocx:
             with_text_replaced = os.path.join(temp_dir, "with_text_replaced.docx")
             input_context.save(with_text_replaced)
             with DocxReader(with_text_replaced) as output_context:
-                output_runs = output_context.file_of_type("officeDocument").content
+                output_runs = output_context.file_of_type("officeDocument").text
         output_text = "".join(iter_at_depth(output_runs, 5))
         assert "bullet" not in output_text
         assert "BULLET" in output_text
@@ -119,12 +118,12 @@ class TestPullImageFiles:
         """Copy image files to output path."""
         docx_context = DocxReader(example_docx)
         with tempfile.TemporaryDirectory() as image_folder:
-            docx_context.pull_image_files(image_folder)
+            _ = docx_context.pull_image_files(image_folder)
             assert set(os.listdir(image_folder)) == {"image1.png", "image2.jpg"}
 
     def test_no_image_files(self) -> None:
         """Pass silently when no image files."""
         docx_context = DocxReader(RESOURCES / "basic.docx")
         with tempfile.TemporaryDirectory() as image_folder:
-            docx_context.pull_image_files(image_folder)
+            _ = docx_context.pull_image_files(image_folder)
             assert os.listdir(image_folder) == []
