@@ -10,8 +10,7 @@ from a doc that raises a CaretDepthError.
 import pytest
 
 from docx2python.main import docx2python
-
-from .conftest import RESOURCES
+from tests.conftest import RESOURCES
 
 
 class TestLibreofficeConversion:
