@@ -27,8 +27,7 @@ an href.
 from paragraphs import par
 
 from docx2python.main import docx2python
-
-from .conftest import RESOURCES
+from tests.conftest import RESOURCES
 
 
 class TestTocText:
